diff mbox

Spelling fixes in comments and macro names (ressource -> resource)

Message ID 1345122741-32492-1-git-send-email-sw@weilnetz.de
State Accepted
Headers show

Commit Message

Stefan Weil Aug. 16, 2012, 1:12 p.m. UTC
Macro XEN_HOST_PCI_RESOURCE_BUFFER_SIZE is only used locally,
so the change should be safe.

Signed-off-by: Stefan Weil <sw@weilnetz.de>
---
 hw/xen-host-pci-device.c |    6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

Comments

Stefan Hajnoczi Aug. 16, 2012, 1:32 p.m. UTC | #1
On Thu, Aug 16, 2012 at 03:12:21PM +0200, Stefan Weil wrote:
> Macro XEN_HOST_PCI_RESOURCE_BUFFER_SIZE is only used locally,
> so the change should be safe.
> 
> Signed-off-by: Stefan Weil <sw@weilnetz.de>
> ---
>  hw/xen-host-pci-device.c |    6 +++---
>  1 file changed, 3 insertions(+), 3 deletions(-)

Thanks, applied to the trivial patches tree:
https://github.com/stefanha/qemu/commits/trivial-patches

Stefan
Andreas Färber Aug. 16, 2012, 2:10 p.m. UTC | #2
Am 16.08.2012 15:32, schrieb Stefan Hajnoczi:
> On Thu, Aug 16, 2012 at 03:12:21PM +0200, Stefan Weil wrote:
>> Macro XEN_HOST_PCI_RESOURCE_BUFFER_SIZE is only used locally,
>> so the change should be safe.
>>
>> Signed-off-by: Stefan Weil <sw@weilnetz.de>
>> ---
>>  hw/xen-host-pci-device.c |    6 +++---
>>  1 file changed, 3 insertions(+), 3 deletions(-)
> 
> Thanks, applied to the trivial patches tree:
> https://github.com/stefanha/qemu/commits/trivial-patches

CC'ing the Xen folks.

Andreas
diff mbox

Patch

diff --git a/hw/xen-host-pci-device.c b/hw/xen-host-pci-device.c
index e7ff680..743b37b 100644
--- a/hw/xen-host-pci-device.c
+++ b/hw/xen-host-pci-device.c
@@ -47,13 +47,13 @@  static int xen_host_pci_sysfs_path(const XenHostPCIDevice *d,
 }
 
 
 /* This size should be enough to read the first 7 lines of a ressource file */
 #define XEN_HOST_PCI_RESSOURCE_BUFFER_SIZE 400
 static int xen_host_pci_get_resource(XenHostPCIDevice *d)
 {
     int i, rc, fd;
     char path[PATH_MAX];
-    char buf[XEN_HOST_PCI_RESSOURCE_BUFFER_SIZE];
+    char buf[XEN_HOST_PCI_RESOURCE_BUFFER_SIZE];
     unsigned long long start, end, flags, size;
     char *endptr, *s;
     uint8_t type;
@@ -47,13 +47,13 @@  static int xen_host_pci_sysfs_path(const XenHostPCIDevice *d,
 
 
-/* This size should be enough to read the first 7 lines of a ressource file */
-#define XEN_HOST_PCI_RESSOURCE_BUFFER_SIZE 400
+/* This size should be enough to read the first 7 lines of a resource file */
+#define XEN_HOST_PCI_RESOURCE_BUFFER_SIZE 400
 static int xen_host_pci_get_resource(XenHostPCIDevice *d)
 {